diff --git a/xc_search/import/xc_search_display_template_element.xml b/xc_search/import/xc_search_display_template_element.xml
index a96e59a..b0dc5ce 100644
--- a/xc_search/import/xc_search_display_template_element.xml
+++ b/xc_search/import/xc_search_display_template_element.xml
@@ -167,4 +167,79 @@ elseif (isset({dcterms:date})) {
   return xc_util_get_metadata_value({dcterms:date});
 }</template>
     </xc_search_display_template_element>
+	
+  <!-- Display template elements for OAI_DC
+  title, creator, format, date, publisher, language, subject. 
+  Table xc_search_display_template_element -->
+    <xc_search_display_template_element>
+        <element_name>title</element_name>
+        <metadata_schema>oai_dc</metadata_schema>
+        <entity_type>oai_dc</entity_type>
+        <template>if (isset({dc:title})) {
+return xc_util_get_metadata_value({dc:title});
+}
+		</template>
+    </xc_search_display_template_element>
+	
+	<xc_search_display_template_element>
+        <element_name>creator</element_name>
+        <metadata_schema>oai_dc</metadata_schema>
+        <entity_type>oai_dc</entity_type>
+        <template>	if (isset({dc:creator})) {
+return xc_util_get_metadata_value({dc:creator});
+}
+		</template>
+    </xc_search_display_template_element>
+	
+	<xc_search_display_template_element>
+        <element_name>format</element_name>
+        <metadata_schema>oai_dc</metadata_schema>
+        <entity_type>oai_dc</entity_type>
+        <template>if (isset({dc:format})) {
+return xc_util_get_metadata_value({dc:format});
+}
+		</template>
+    </xc_search_display_template_element>
+	
+	<xc_search_display_template_element>
+        <element_name>date</element_name>
+        <metadata_schema>oai_dc</metadata_schema>
+        <entity_type>oai_dc</entity_type>
+        <template>if (isset({dc:date})) {
+return xc_util_get_metadata_value({dc:date});
+}
+		</template>
+    </xc_search_display_template_element>
+	
+	<xc_search_display_template_element>
+        <element_name>publisher</element_name>
+        <metadata_schema>oai_dc</metadata_schema>
+        <entity_type>oai_dc</entity_type>
+        <template>if (isset({dc:publisher})) {
+return xc_util_get_metadata_value({dc:publisher});
+}
+		</template>
+    </xc_search_display_template_element>
+	
+	
+	<xc_search_display_template_element>
+        <element_name>language</element_name>
+        <metadata_schema>oai_dc</metadata_schema>
+        <entity_type>oai_dc</entity_type>
+        <template>if (isset({dc:language})) {
+return xc_util_get_metadata_value({dc:language});
+}
+		</template>
+    </xc_search_display_template_element>
+	
+	
+	<xc_search_display_template_element>
+        <element_name>subject</element_name>
+        <metadata_schema>oai_dc</metadata_schema>
+        <entity_type>oai_dc</entity_type>
+        <template>if (isset({dc:subject})) {
+return xc_util_get_metadata_value({dc:subject});
+}
+		</template>
+    </xc_search_display_template_element>
 </drupal_test_merge>
diff --git a/xc_search/templates/oai_dc-full-mlt.tpl.php b/xc_search/templates/oai_dc-full-mlt.tpl.php
new file mode 100644
index 0000000..462eceb
--- /dev/null
+++ b/xc_search/templates/oai_dc-full-mlt.tpl.php
@@ -0,0 +1,41 @@
+<?php
+/**
+ * @file
+ * Template for the full record display’s More Like This listing element.
+ *
+ * Variables:
+ * - $node_id (int): the node identifier
+ * - $link (string): the link to node
+ * - $image_url: the ural of cover image
+ * - $title_link: the linked litle
+ * - $title_clean: the cleaned title, which contains no HTML tags
+ * - $creator: the creator of the item
+ * - $count: the count number
+ * - $show: whether to show template of not
+ *
+ * @copyright (c) 2010-2011 eXtensible Catalog Organization
+ */
+?>
+<?php if ($show): ?>
+
+  <div class="xc-mlt">
+    <div class="xc-mlt-count"><?php print $count; ?></div>
+
+    <?php if (isset($image_url)): ?>
+      <span id="coverart-<?php print $node_id; ?>" class="xc-mlt-coverart coverart">
+        <a href="<?php print $link; ?>" title="<?php print $title_clean; ?>"><img src="<?php print $image_url; ?>"
+          alt="<?php print t('Cover image of !title', array('!title' => $title_clean)); ?>"
+          title="<?php print t('Cover image of !title', array('!title' => $title_clean)); ?>"
+          class="xc-mlt-coverart-img"/></a>
+      </span>
+    <?php endif; ?>
+
+    <?php if ($title_link): ?>
+      <span class="xc-mlt-title"><?php print $title_link; ?></span>
+
+      <?php if ($creator): ?>
+        <span class="xc-mlt-author" title="<?php print $all_creators; ?>">by <?php print $creator; ?></span>
+      <?php endif; ?>
+    <?php endif; ?>
+  </div>
+<?php endif ?>
\ No newline at end of file
diff --git a/xc_search/templates/oai_dc-full.tpl.php b/xc_search/templates/oai_dc-full.tpl.php
new file mode 100644
index 0000000..1d341e0
--- /dev/null
+++ b/xc_search/templates/oai_dc-full.tpl.php
@@ -0,0 +1,304 @@
+<?php
+/**
+ * @file
+ * Template for manifestation’s full record display
+ *
+ * @copyright (c) 2010-2011 eXtensible Catalog Organization
+ */
+?>
+
+<div id="xc-search-full">
+
+  <?php /*  THE RIGHT SIDEBAR - images and action buttons*/ ?>
+  <div id="xc-search-full-right">
+    <div id="coverart-<?php print $node_id; ?>" class="coverart">
+      <?php if ($image_url_large): ?>
+        <a href="<?php print $image_url_large ?>" rel="lightbox"
+           title="<?php if ($title): ?><?php print $title; ?><?php endif?><?php if ($creator): ?> by <?php print $creator; ?><?php endif?>">
+          <img src="<?php print $image_url_medium; ?>" alt="" />
+        </a>
+      <?php elseif ($image_url_medium): ?>
+        <img src="<?php print $image_url_medium; ?>" alt="" />
+      <?php endif; ?>
+    </div>
+
+    <div id="buttons-<?php print $node_id; ?>" class="buttons">
+      <?php print $action_buttons; ?>
+    </div>
+  </div>
+
+  <div id="xc-search-full-left">
+
+    <table class="xc-search-full-table">
+      <?php if ($title): ?>
+        <tr>
+          <td class="xc-label"><?php print t('Title'); ?>:</td>
+          <td class="xc-title"><?php print $title; ?></td>
+        </tr>
+      <?php endif; ?>
+
+      <?php if (isset($top_author_links)): ?>
+        <tr>
+          <td class="xc-label"><?php print t('Creators/Authors'); ?>:</td>
+          <td><?php print $top_author_links; ?></td>
+        </tr>
+      <?php endif; ?>
+
+      <?php if ($publisher || $date): ?>
+        <tr>
+          <td class="xc-label"><?php print t('Publication info'); ?>:</td>
+          <td>
+          <?php if ($publisher): ?>
+            <?php print $publisher; ?>
+          <?php endif; ?>
+
+          <?php if ($date): ?>
+            <?php print $date; ?>
+          <?php endif; ?>
+          </td>
+        </tr>
+      <?php endif ?>
+
+      <?php if ($format || $language): ?>
+        <tr>
+          <td class="xc-label"><?php print t('Edition/Format'); ?>:</td>
+          <td>
+            <?php if ($format): ?><span class="xc-format"><?php print $format; ?></span><?php endif; ?>
+            <?php if ($format && ($language || isset($editionStatement))) : ?>; <?php endif; ?>
+            <?php if ($language): ?><?php print $language; ?><?php endif; ?>
+            <?php if ($language && $editionStatement): ?>; <?php endif; ?>
+            <?php if (isset($editionStatement)): ?><?php print $editionStatement; ?><?php endif; ?>
+          </td>
+        </tr>
+      <?php endif; ?>
+
+      <?php if (!empty($url_identifiers)): ?>
+        <tr>
+          <td class="xc-label"><?php print t('Location'); ?>:</td>
+          <td><?php print theme('item_list', $url_identifiers); ?></td>
+        </tr>
+      <?php endif; ?>
+
+      <?php if (isset($format)):?>
+        <tr>
+          <td class="xc-label"><?php print t('Document Type'); ?>:</td>
+          <td><?php print $format; ?></td>
+        </tr>
+      <?php endif; ?>
+
+      <?php if (isset($all_author_links)): ?>
+        <tr class="xc-other-contributors">
+          <td class="xc-label"><?php print t('Other contributors'); ?>:</td>
+          <td><?php print theme('item_list', $all_author_links); ?></td>
+        </tr>
+      <?php endif; ?>
+
+      <?php if (isset($ISBN) && !empty($ISBN)): ?>
+        <tr>
+          <td class="xc-label"><?php print t('ISBN'); ?>:</td>
+          <td><?php print $ISBN; ?></td>
+        </tr>
+      <?php endif; ?>
+
+      <?php if ($ISSN): ?>
+        <tr>
+          <td class="xc-label"><?php print t('ISSN'); ?>:</td>
+          <td><?php print $ISSN; ?></td>
+        </tr>
+      <?php endif; ?>
+
+      <?php if ($description): ?>
+        <tr>
+          <td class="xc-label"><?php print t('Description'); ?>:</td>
+          <td>
+            <?php print $description; ?>
+          </td>
+        </tr>
+      <?php endif; ?>
+
+
+      <?php if (isset($relations)): ?>
+        <tr id="xc-search-related-resources">
+          <td class="xc-label"><?php print t('Related Resources'); ?>:</td>
+          <td>
+          <?php if (count($relations) == 1) : ?>
+            <?php print $relations[0]; ?>
+          <?php else: ?>
+            <?php print theme('item_list', $relations, '', 'ul', array('class' => 'xc-relations')); ?>
+          <?php endif; ?>
+          </td>
+        </tr>
+      <?php endif; ?>
+
+      <?php if ($subject): ?>
+        <tr id="subject-topic" class="xc-search-subjects">
+          <td class="xc-label"><?php print t('Subject'); ?>:</td>
+          <td><?php print theme('item_list', $subject); ?></td>
+        </tr>
+      <?php endif; ?>
+
+
+      <?php if (!empty($enhancements)): ?>
+        <?php foreach ($enhancements as $module => $enhancement): ?>
+          <tr class="enhancement-title" <?php if (isset($enhancement['meta']['id'])): ?>id="<?php print $enhancement['meta']['id']; ?>"<?php endif; ?>>
+            <td class="xc-label"></td>
+            <td class="enhancement-title">
+              <?php if (isset($enhancement['meta']['title'])): ?>
+                <?php print $enhancement['meta']['title']; ?>
+              <?php endif; ?>
+            </td>
+          </tr>
+          <?php if (isset($enhancement['content'])): ?>
+            <?php foreach ($enhancement['content'] as $key => $value) : ?>
+              <tr class="enhancement-content">
+                <td class="xc-label"><?php print $key; ?>:</td>
+                <td><?php print $value; ?></td>
+              </tr>
+            <?php endforeach; ?>
+          <?php endif; ?>
+        <?php endforeach; ?>
+      <?php endif ?>
+
+      <?php
+
+        // processed fields for admin viewing only
+        $processed_fields = array(
+          'id',
+          'node_id',
+          'timestamp',
+          'type',
+          'node_type',
+          'processed',
+          'metadata_id',
+          'metadata_type',
+          'syndetics_ids',
+          'image_url',
+          'dcterms:tableOfContents',
+          'rdvocab:titleOfWork',
+          'dcterms:description',
+          'xc:relation',
+          'dcterms:relation',
+          'rdvocab:placeOfPublication',
+          'xc:workExpressed',
+          'xc:expressionManifested',
+          'xc:recordID_OCoLC',
+          'dcterms:extent',
+          'mlt',
+          'xc:subject',
+          'dcterms:subject',
+          'rdvocab:natureOfContent',
+          'dcterms:identifier_ISBN',
+          'summary',
+          'language',
+          'xc:isPartOf',
+          'dcterms:isPartOf',
+          'rdvocab:placeOfProduction',
+          'dcterms:identifier',
+          'rdvocab:editionStatement',
+          'mlts',
+          'holdings_summary',
+          'rdvocab:statementOfResponsibilityRelatingToTitle',
+          'dcterms:audience',
+
+          // display template elements
+          'dcterms:language',
+          'xc:spacial',
+          'xc:spatial',
+
+          // language
+
+          // special fields
+          'image_url_large',
+          'image_url_medium',
+          'status',
+          'serialized_tsn',
+          'locations',
+
+          // facets
+          'format',
+          'classification',
+          'topic',
+          'date',
+          'genre',
+          'subject',
+          'authors_contributors',
+          'other_contributors',
+          'related_resources',
+          'subject_temporal',
+          'subject_topic',
+        );
+
+      ?>
+
+      <?php if (isset($has_admin_rights) && $has_admin_rights == TRUE) foreach ($xc_record as $key => $values): ?>
+        <?php if (!in_array($key, $processed_fields)): ?>
+          <tr>
+            <td class="xc-label"><?php print t($key); ?>:</td>
+            <td>
+              <?php if (is_array($values)) : ?>
+                <?php if (count($values) > 1) : ?>
+                  <ul class="xc-search-subject">
+                    <?php foreach ($values as $value) : ?>
+                      <li><?php print $value['#value']; ?></li>
+                    <?php endforeach; ?>
+                  </ul>
+                <?php else: ?>
+                  <?php print $values[0]['#value']; ?>
+                <?php endif; ?>
+              <?php else: ?>
+                <?php print $values; ?>
+              <?php endif; ?>
+            </td>
+          </tr>
+        <?php endif; ?>
+      <?php endforeach; ?>
+    </table>
+
+  </div>
+
+</div>
+
+<!------------------------------------------------------------------------------
+
+  NOTE: Enhancements, related subject topics, regions, time periods, and
+  resources are disabled in the default XC theme
+
+<?php /*********************** DISABLED IN THEME *******************************
+
+
+*****************************************************************************/?>
+------------------------------------------------------------------------------->
+
+<?php if (isset($mlts)): ?>
+  <?php $count = 1; $image_mlts = ''; ?>
+  <?php foreach ($mlts as $mlt): ?>
+    <?php $image_mlts .= trim(theme('oai_dc_full_mlt', $mlt, $count, 'image')); ?>
+    <?php $count++; ?>
+  <?php endforeach; ?>
+
+  <?php $count = 1; $title_mlts = array(); ?>
+  <?php foreach ($mlts as $mlt): ?>
+    <?php $title_mlts[] = trim(theme('oai_dc_full_mlt', $mlt, $count, 'title')); ?>
+    <?php $count++; ?>
+  <?php endforeach; ?>
+
+  <div id="xc-search-similar-items">
+    <h3 class="title"><?php print t('Similar Items'); ?>:</h3>
+
+    <?php /* print out images */ ?>
+    <?php if ($image_mlts): ?>
+      <div id="xc-search-similar-items-images">
+        <?php print $image_mlts; ?>
+        <div style="clear:both;"></div>
+      </div>
+    <?php endif; ?>
+
+    <?php /* print out list */ ?>
+    <?php if ($title_mlts): ?>
+      <div id="xc-search-similar-items-titles">
+        <?php print theme('xc_multicolumn_table', $title_mlts, 2) ?>
+        <div style="clear:both;"></div>
+      </div>
+    <?php endif; ?>
+  </div>
+<?php endif; ?>
\ No newline at end of file
diff --git a/xc_search/templates/oai_dc-title.tpl.php b/xc_search/templates/oai_dc-title.tpl.php
index eceabd6..4efe9a8 100644
--- a/xc_search/templates/oai_dc-title.tpl.php
+++ b/xc_search/templates/oai_dc-title.tpl.php
@@ -1,13 +1,21 @@
 <?php
 /**
  * @file
- * Title template for OAI DC
+ * Title template for manifestation
  *
  * @copyright (c) 2010-2011 eXtensible Catalog Organization
  */
 ?>
-<?php if (isset($xc_record['dc:title'])): ?>
-  <?php print l(xc_util_conditional_join(', ', $xc_record['dc:title']), $xc_record['full_display_url']); ?>
-<?php else: ?>
-  <?php print 'non title'; ?>
-<?php endif; ?>
+<?php timer_start('theme_xc_search_metadata/oai_dc_title/theme'); ?>
+<?php if (!empty($title_link)) : ?>
+  <div class="xc-title">
+    <?php print $title_link; ?>
+  </div>
+<?php endif ?>
+
+<?php if (!empty($creator_link)) : ?>
+  <div class="xc-creator">
+    by <span class="xc-creator-name"><?php print $creator_link; ?></span>
+  </div>
+<?php endif ?>
+<?php timer_stop('theme_xc_search_metadata/oai_dc_title/theme'); ?>
diff --git a/xc_search/xc_search.module b/xc_search/xc_search.module
index 34da4cd..34ee012 100644
--- a/xc_search/xc_search.module
+++ b/xc_search/xc_search.module
@@ -4139,7 +4139,7 @@ function xc_search_full_action_form(&$form_state, $xc_record) {
   $form = array(
     '#theme' => 'xc_search_full_action_form',
   );
-  $bookmark_id = xc_account_get_bookmark_id($user->uid, $nid);
+  //FIXME: let PK know $bookmark_id = xc_account_get_bookmark_id($user->uid, $nid);
 
   $form['uid'] = array(
     '#type' => 'hidden',
@@ -4480,6 +4480,320 @@ function template_preprocess_manifestation_snippet(&$variables) {
   }
 } // template_preprocess_manifestation_snippet
 
+
+
+/**
+ * :Than
+ * Preprocess template variables for oai_dc snippet.
+ *
+ * Preserved variables: template_files, zebra, directory, is_admin, is_front,
+ * logged_in, db_is_active, user
+ * Parameters: base_url, id, xc_record, element, frbr
+ *
+ * @param $variables
+ */
+function template_preprocess_oai_dc_snippet(&$variables) {
+  static $link_options, $online_link_strategy;
+
+  // TODO:
+  // problems:
+  // $variables['xc_record']['dcterms:extent'] always contains a ' :' at the end
+
+  $variables['publisher'] = xc_util_conditional_join(', ', $variables['element']['publisher']);
+  $variables['date'] = xc_util_conditional_join(', ', $variables['element']['date']);
+  $variables['format'] = xc_util_conditional_join(', ', $variables['element']['format']);
+
+  //$variables['format'] = xc_search_get_manifestation_formats($variables['xc_record']['format']);  $variables['is_journal'] = preg_match('/\b' . t('Journals') . '\b/', $variables['format']);
+
+  if (isset($variables['xc_record']['dc:identifier'])
+      && xc_util_contains_url(xc_util_get_metadata_value($variables['xc_record']['dc:identifier']))) {
+    $variables['get_availability'] = FALSE;
+    $variables['online_links'] = xc_util_get_metadata_value($variables['xc_record']['dc:identifier']);
+	}
+}	// template_preprocess_manifestation_snippet
+
+
+
+/**
+* :Than OAI_DC title template
+* It uses Title and creator display template elements. So make sure that they are added via XC Admin interface
+**/
+function template_preprocess_oai_dc_title(&$variables) {
+  timer_start('theme_xc_search_metadata/oai_dc_title/template_preprocess');
+
+  $variables['title'] = xc_util_conditional_join(' &mdash; ', $variables['element']['title']);
+  $creators = (array)$variables['element']['creator'];
+  if (count($creators) > 1) {
+    $ui = xc_search_variable('search_ui');
+    switch ($ui->authors_count) {
+      // all creators
+      case -1: break;
+      // none of them
+      case 0:
+        $creators = array();
+        break;
+
+      default:
+        $has_more = (count($creators) > $ui->authors_count);
+        $creators = array_slice($creators, 0, $ui->authors_count);
+        if ($has_more) {
+          $creators[] = '&hellip;';
+        }
+        break;
+    }
+   }
+   
+     $variables['creator'] = xc_util_conditional_join(' &mdash; ', $creators);
+
+  if (!empty($variables['xc_record']['full_display_url'])) {
+    $variables['title_link'] = l(
+      $variables['title'],            // link text
+      $variables['xc_record']['full_display_url'], // URL full_display_url
+      array('html' => TRUE, 'absolute' => TRUE)
+    );
+    if (!empty($variables['creator'])) {
+      $variables['creator_link'] = l(
+        $variables['creator'],
+        $variables['xc_record']['full_display_url'],
+        array('html' => TRUE, 'absolute' => TRUE)
+      );
+    }
+  }
+  else {
+    $variables['title_link'] = $variables['title'];
+    if (!empty($variables['creator'])) {
+      $variables['creator_link'] = $variables['creator'];
+    }
+  }
+  timer_stop('theme_xc_search_metadata/oai_dc_title/template_preprocess');
+}
+
+
+/**
+ * :Than
+ * Preprocess full display template for OAI_DC
+ * @param $variables
+ */
+
+function template_preprocess_oai_dc_full(&$variables) {
+  timer_start('template_preprocess_oai_dc_full');
+
+  $author_field_names = array('dc:creator' => t('creator'));
+  
+  $contributor_field_names = array('dcterms:contributor' => t('contributor'));
+
+  $authors_contibutors = array();
+  
+  //create author links form dc:creator
+  if (is_array($variables['xc_record']['dc:creator'])) {
+    $creators = array_unique((array)$variables['xc_record']['creator_author']);
+  }
+  $links = array();
+  $link_options = array(
+    'phrase' => 1,
+    'facet' => 1,
+  );
+  foreach ($creators as $creator) {
+    $links[] = array(
+      xc_util_make_link($creator, 'creator_author_fc', $link_options),
+      l(t('(Search WorldCat Identities)'), 'xc_search/ajax/open_worldcat_identity_url',
+        array('query' => 'sURL=' . rawurlencode($creator))),
+    );
+  }
+  if (!empty($links)) {
+    if (count($links) == 1) {
+      $variables['top_author_links'] = $links[0][0] . ' &nbsp; ' . $links[0][1];
+    }
+    elseif (count($links) <= 4) {
+      $variables['top_author_links'] = theme('table', array(), $links, array('id' => 'xc-authors-list'));
+    }
+    else { //if it's more than four creators, then hide the rest
+      $items = array();
+      foreach ($links as $i => $link) {
+        if ($i < 4) {
+          $items[] = $link;
+        }
+        else {
+          $items[] = array('data' => $link, 'class' => 'xc-hidden-author');
+        }
+      }
+      $items[] = array(
+        'data' => array(t('<a href="#">!count more</a>',
+                  array('!count' => intval(count($links)-4)))),
+        'id' => 'xc-show-hidden-authors'
+      );
+      $variables['top_author_links'] = theme('table', array(), $items, array('id' => 'xc-authors-list'));
+      drupal_add_js(drupal_get_path('module', 'xc_search') . '/js/xc_manifestation.js');
+    }
+  }
+
+  //end of getting author links
+  
+  foreach ($contributor_field_names as $field_name => $label) {
+    if (isset($variables['xc_record'][$field_name])) {
+      if (is_array($variables['xc_record'][$field_name])) {
+        foreach (xc_util_get_metadata_value($variables['xc_record'][$field_name]) as $author) {
+          $authors_contibutors[$author]['fields'][] = $field_name;
+          $authors_contibutors[$author]['labels'][] = $label;
+        }
+      }
+      else {
+        $authors_contibutors[$variables['xc_record'][$field_name]]['fields'][] = $field_name;
+        $authors_contibutors[$variables['xc_record'][$field_name]]['labels'][] = $label;
+      }
+    }
+  }
+
+  $links = array();
+  foreach ($authors_contibutors as $contributor => $info) {
+    // it retrieves always ONE link
+    $raw_links = xc_util_conditional_joined_link(NULL, $contributor,
+      'other_contributors_fc', array('phrase' => 1, 'facet' => 1, 'debug' => 1));
+    foreach ($raw_links as $link) {
+      $links[] = $link . ' ('. join(', ', $info['labels']) . ')';
+    }
+  }
+  if (!empty($links)) {
+    $variables['all_author_links'] = $links;
+  }
+
+  $variables['ajax_loader_img'] = drupal_get_path('module', 'xc_search') . '/images/ajax-loader.gif';
+
+  /*
+  $variables['publisher'] = xc_util_conditional_joined_link(', ',
+    $variables['element']['publisher'], 'dcterms:publisher');
+    */
+  $variables['publisher'] = xc_util_conditional_join(', ', $variables['element']['publisher']);
+
+  $variables['date'] = xc_util_conditional_join(', ', $variables['element']['date']);
+  // $variables['format'] = xc_util_conditional_join(', ', $variables['element']['format']);
+  $variables['format'] = xc_search_get_manifestation_formats($variables['xc_record']['format']);
+
+  $variables['language'] = xc_util_conditional_join('&mdash;', $variables['element']['language']);
+  $variables['title'] = xc_util_conditional_join(', ', $variables['element']['title']);
+  $variables['creator'] = xc_util_conditional_join(', ', $variables['element']['creator']);
+
+  $variables['node_id'] = $variables['xc_record']['node_id'];
+  $variables['image_url_large'] = $variables['xc_record']['image_url_large'];
+  $variables['image_url_medium'] = $variables['xc_record']['image_url_medium'];
+
+  /**
+  // ISBN
+  if (isset($variables['xc_record']['dcterms:identifier'])) {
+    $variables['ISBN'] = xc_util_conditional_join(' &mdash; ', xc_util_get_metadata_value($variables['xc_record']['dcterms:identifier'], array('@type' => 'ISBN')));
+  }
+
+  // ISSN
+  $variables['ISSN'] = xc_util_conditional_join(' &mdash; ',
+    xc_util_get_metadata_values($variables['xc_record'], array(
+      'dcterms:identifier' => array('@type' => 'ISSN'),
+      'xc:identifier' => array('@type' => 'ISSN')
+    )
+  ));
+  **/
+  
+
+  $fields = array(
+    'description' => 'dc:description',
+	'coverage' => 'dc:coverage',
+	'rights' => 'dc:rights',
+	'source' => 'dc:source',
+  );
+  foreach ($fields as $variable => $schemafield) {
+    if (isset($variables['xc_record'][$schemafield])) {
+      $variables[$variable] = xc_util_conditional_join(
+        ' &mdash; ',
+        xc_util_get_metadata_value($variables['xc_record'][$schemafield])
+      );
+    }
+  }
+  //$variables['summary'] = xc_util_conditional_join('<br/>', $variables['xc_record']['summary']);
+
+  $subj_key = 'dc:subject';
+  $subj_name = 'subject';
+  // applying subject_spatial, subject_topic, subject_temporal
+  if ( !empty($variables['xc_record'][$subj_key])) {
+	$subjects = xc_util_get_metadata_value($variables['xc_record'][$subj_key]);
+    $solr_field =  $subj_name . '_fc';
+	foreach ($subjects as $term) {
+      $solr_query = $solr_field . ':"' . $term . '"';
+      $variables[$subj_name][] = l($term,
+        'xc/search/*', // . urlencode($solr_query),
+        array('query' => array(
+          'filter' => array($solr_query),
+          'reuse_filter' => 1,
+          'ql' => 1)
+        )
+      );
+    }
+  } 
+
+  $identifiers = array();
+  if (isset($variables['xc_record']['dc:identifier'])) {
+    $identifiers = xc_util_get_metadata_value($variables['xc_record']['dc:identifier']);
+    if (!is_array($identifiers)) {
+      $identifiers = array($identifiers);
+    }
+  }
+  
+  // if the dc:identifier is a URL link create a link
+  $variables['url_identifiers'] = array();
+  $options = array(
+    'external' => 1,
+    'regex' => '{(https?|ftp)://[^ ]+}',
+    'shorten' => 1,
+  );
+  foreach ($identifiers as $identifier) {
+    if (preg_match("{(https?|ftp)://[^ ]+}", $identifier)) {
+      $variables['url_identifiers'][] = xc_util_make_link($identifier, '', $options);
+    }
+  }
+
+  $variables['has_admin_right'] = user_access(ADMINISTER_XC_SEARCH);
+
+  $relations = array();
+  if (!empty($variables['xc_record']['dc:relation'])) {
+    $relations = xc_util_get_metadata_value($variables['xc_record']['dc:relation']);
+  }
+
+  if (!empty($relations)) {
+    xc_util_link_walk($relations, '', array('external' => 1, 'regex' => '{(https?|ftp)://[^ ]+}'));
+    $variables['relations'] = $relations;
+  }
+  
+  $variables['mlts'] =& $variables['xc_record']['mlts'];
+  $variables['enhancements'] = $variables['xc_record']['enhancements'];
+  $variables['action_buttons'] =& $variables['xc_record']['action_buttons'];
+
+  timer_stop('template_preprocess_oai_dc_full');
+}//template_preprocess_oai_dc_full
+
+/**
+ * :Than preprocess function for oai_dc_full_mlt theme
+ * 
+ * @param $variables (Array)
+ *   The variables available to the theme
+ */
+function template_preprocess_oai_dc_full_mlt(&$variables) {
+  $variables += $variables['mlt'];
+  if ($variables['show'] == 'title') {
+    $variables['show'] = ($variables['title_link']);
+    unset($variables['image_url']);
+  }
+  elseif ($variables['show'] == 'image') {
+    $variables['show'] = ($variables['image_url']);
+    unset($variables['title_link']);
+  }
+  elseif ($variables['title_link'] || $variables['image_url']) {
+    $variables['show'] = TRUE;
+  }
+  else {
+    $variables['show'] = FALSE;
+  }
+}//template_preprocess_oai_dc_full_mlt
+
+
+
 function template_preprocess_manifestation_title(&$variables) {
   timer_start('theme_xc_search_metadata/manifestation_title/template_preprocess');
 
@@ -5089,6 +5403,16 @@ function xc_search_theme() {
         'show' => TRUE,
       ),
     ),
+	//:Than OAI_DC more like this template
+	'oai_dc_full_mlt' => array(
+      'template'  => 'templates/oai_dc-full-mlt',
+      'arguments' => array(
+        'mlt' => NULL,
+        'count' => NULL,
+        'show' => TRUE,
+      ),
+    ),
+	
     'xc_search_no_results' => array(
       'arguments' => array('title' => NULL, 'content' => NULL),
     ),
diff --git a/xc_solr/xc_solr.index.inc b/xc_solr/xc_solr.index.inc
index 8925626..fe2c9a6 100644
--- a/xc_solr/xc_solr.index.inc
+++ b/xc_solr/xc_solr.index.inc
@@ -258,8 +258,7 @@ function xc_solr_onestop_indexer($metadata_id) {
   $document->addField('metadata_tsn',  serialize($metadata), FALSE, TRUE);
   $document->setField('text', join(' ', $document->text));
   //Fix for SEVERE: org.apache.solr.common.SolrException: ERROR:unknown field 'highlight_txt'
-
-  $document->setField('highlight_t', join(' ', $document->highlight));
+  $document->setField('highlight_t', $document->highlight);
 
   $ft1 = microtime(TRUE);
 
@@ -965,7 +964,9 @@ function xc_solr_metadata_to_solr_iterate_indexes(&$object, &$document = NULL) {
           foreach ($element_instance as $key => $value) {
             if ($key == '#value') {
               $all_fields .= $value . ' ';
-              if (!in_array($field, $cache['not_in_highlight'])) {
+			  //Fix for the error warning: in_array() expects parameter 2 to be array, 
+			  //null given in /var/www/xc-patch/sites/all/modules/xc/xc_solr/xc_solr.index.inc on line 968.
+              if (!is_array($cache['not_in_highlight']) || !in_array($field, $cache['not_in_highlight'])) {
                 $highlight .= $value . ' ';
               }
             } // foreach element_instances

diff --git a/xc_search/templates/oai_dc-snippet.tpl.php b/xc_search/templates/oai_dc-snippet.tpl.php
index 4c3f4e5..14ced06 100644
--- a/xc_search/templates/oai_dc-snippet.tpl.php
+++ b/xc_search/templates/oai_dc-snippet.tpl.php
@@ -1,11 +1,89 @@
 <?php
 /**
  * @file
  * Snippet template for OAI DC record
  *
  * @copyright (c) 2010-2011 eXtensible Catalog Organization
  */
+
+// FIXME: This should be pre-processed with variables since many of the labels
+//        are not translatable. Could also be partitioned or divided into sections
+//        and turned into smaller template files.
 ?>
-<?php if (isset($xc_record['dc:description'])): ?>
-  <?php print $xc_record['dc:description']; ?>
+<table class="xc-snippet">
+<tr class="xc-format">
+  <td class="snippet-label"><?php print t('Format'); ?>:</td>
+  <td<?php if (isset($format_classes)): ?> class="<?php print $format_classes; ?>"<?php endif; ?>>
+    <?php if (!empty($format)) : ?>
+      <?php print $format; ?>
+    <?php endif; ?>
+  </td>
+</tr>
+
+<?php if ($get_availability) : ?>
+<tr class="xc-availability">
+  <td class="snippet-label"><?php print t('Location'); ?>:</td>
+  <td id="xc-availability-<?php print $xc_record['node_id']; ?>"
+    class="xc-availability <?php if ($is_journal) : ?>xc_journal<?php endif; ?>"><?php print t('loading&hellip;')?></td>
+</tr>
+<tr id="xc-call-number-row-<?php print $xc_record['node_id']; ?>" class="xc-call-number">
+  <td class="snippet-label"><?php print t('Call number'); ?>:</td>
+  <td id="xc-call-number-<?php print $xc_record['node_id']; ?>"
+    class="xc-availability <?php if ($is_journal) : ?>xc_journal<?php endif; ?>"><?php print t('loading&hellip;')?></td>
+</tr>
+<?php else :?>
+  <?php if (!empty($online_links)) : ?>
+<tr class="xc-online">
+  <td class="snippet-label"><?php print t('Location'); ?>:</td>
+  <td><?php print join(', ', $online_links); ?></td>
+</tr>
+  <?php endif; ?>
 <?php endif; ?>
+
+<?php if (!empty($date)) : ?>
+<tr class="xc-date">
+  <td class="snippet-label"><?php print t('Date'); ?>:</td>
+  <td><?php print $date; ?></td>
+</tr>
+<?php endif ?>
+
+<?php if (!empty($publisher) || !empty($placeOfProduction)) : ?>
+<tr class="xc-date">
+  <td class="snippet-label"><?php print t('Published'); ?>:</td>
+  <td>
+    <?php if (!empty($placeOfProduction)) : ?>
+      <?php print $placeOfProduction; ?>
+    <?php endif; ?>
+    <?php if (!empty($publisher)) : ?>
+      <?php print $publisher; ?>
+    <?php endif; ?>
+  </td>
+</tr>
+<?php endif ?>
+
+<?php if (!empty($citation)) : ?>
+<tr class="xc-citation">
+  <td class="snippet-label"><?php print t('Citation'); ?>:</td>
+  <td><?php print $citation; ?></td>
+</tr>
+<?php endif ?>
+</table>
+
+<?php if ($xc_record['admin']['debug_mode'] == TRUE) : ?>
+  <div class="xc-debug-info">
+    FRBR level: manifestation
+     - [<?php print $xc_record['full_display_link']; ?>]
+     - [<?php print $xc_record['schema_record_link']; ?>]
+     - [<?php print $xc_record['remote_xml_link']; ?>]
+     - [<?php print $xc_record['solr_link']; ?>]
+     - [<?php print $xc_record['mlt_link']; ?>]
+    <?php if (!empty($xc_record['sibling_link'])) : ?>
+     - [<?php print $xc_record['sibling_link']?>]
+    <?php endif; ?>
+    <?php if (!empty($xc_record['oclc_urls'])) : ?> -
+      <?php   foreach ($xc_record['oclc_urls'] as $url) : ?>
+        [<a href="<?php print $url; ?>">oclc</a>]
+      <?php   endforeach; ?>
+    <?php endif; ?>
+</div>
+<?php endif; // debug ?>
\ No newline at end of file
@@ -1,11 +1,89 @@
 /**
  * @file
- * Snippet template for OAI DC record
+ * Snippet template for manifestation
  *
  * @copyright (c) 2010-2011 eXtensible Catalog Organization